%define nsusr nagios
%define nsgrp nagios
%define cmdusr apache
%define cmdgrp apache
%define _disable_ld_no_undefined 1

Summary:    Host/service/network monitoring program
Name:       nagios
Epoch:      1
Version:    4.4.10
Release:    %mkrel 1
License:    GPLv2
Group:      Monitoring
URL:        https://www.nagios.org/
Source0:    https://github.com/NagiosEnterprises/nagioscore/releases/download/nagios-%{version}/nagios-%{version}.tar.gz
Source1:    %{name}.service
Source2:    %{name}.tmpfiles
Source5:    favicon.ico
Patch1:     nagios-4.0.0-conf.d.patch
Requires(post): rpm-helper
Requires(preun): rpm-helper
Requires(pre): rpm-helper
Requires(postun): rpm-helper
Requires:   nagios-plugins
Recommends:   nagios-check_http
Recommends:   nagios-check_ssh
Recommends:   nagios-check_ping
Recommends:   nagios-check_disk
Recommends:   nagios-check_load
Recommends:   nagios-check_procs
Recommends:   nagios-check_users
Recommends:   nagios-check_swap
BuildRequires:  pkgconfig(gdlib)
BuildRequires:  imagemagick
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  libtool-devel
BuildRequires:  multiarch-utils >= 1.0.3
BuildRequires:  perl-devel
Provides:	nagios-agent

%description
Nagios is a program that will monitor hosts and services on your
network. It has the ability to email or page you when a problem
arises and when a problem is resolved. Nagios is written in C and
is designed to run under Linux (and some other *NIX variants) as a
background process, intermittently running checks on various
services that you specify.

The actual service checks are performed by separate "plugin"
programs which return the status of the checks to Nagios.

This package provide core programs for nagios. The web interface,
documentation, and development files are built as separate
packages

%package    www
Summary:    Provides the HTML and CGI files for the Nagios web interface
Group:      Networking/WWW
Requires:   %{name} = %{epoch}:%{version}-%{release}
Requires:   nail
Requires:   traceroute
Requires:   php-webinterface
Epoch:      %{epoch}

%description    www
Nagios is a program that will monitor hosts and services on your network. It
has the ability to email or page you when a problem arises and when a problem
is resolved. Nagios is written in C and is designed to run under Linux (and
some other *NIX variants) as a background process, intermittently running
checks on various services that you specify.

Several CGI programs are included with Nagios in order to allow you to view the
current service status, problem history, notification history, and log file via
the web. This package provides the HTML and CGI files for the Nagios web
interface. In addition, HTML documentation is included in this package

%package    devel
Group:      Development/C
Summary:    Provides include files that Nagios-related applications may compile against
Epoch:      %{epoch}

%description    devel
Nagios is a program that will monitor hosts and services on your network. It
has the ability to email or page you when a problem arises and when a problem
is resolved. Nagios is written in C and is designed to run under Linux (and
some other *NIX variants) as a background process, intermittently running
checks on various services that you specify.

This package provides include files that Nagios-related applications may
compile against.

%prep
%setup -q
%autopatch -p1

%build
%serverbuild

export CFLAGS="%{optflags} -fPIC"
export CXXFLAGS="%{optflags} -fPIC"
export FFLAGS="%{optflags} -fPIC"
%configure \
    --with-httpd-conf=%{_webappconfdir} \
    --with-checkresult-dir=/var/spool/nagios/checkresults \
    --with-temp-dir=/tmp \
    --exec-prefix=%{_sbindir} \
    --bindir=%{_sbindir} \
    --sbindir=%{_libdir}/nagios/cgi \
    --libexecdir=%{_libdir}/nagios/plugins \
    --datadir=%{_datadir}/nagios \
    --sysconfdir=%{_sysconfdir}/nagios \
    --localstatedir=/var/log/nagios \
    --with-lockfile=/run/nagios/nagios.pid \
    --with-mail=/bin/mail \
    --with-nagios-user=%{nsusr} \
    --with-nagios-group=%{nsgrp} \
    --with-command-user=%{cmdusr} \
    --with-command-grp=%{cmdgrp} \
    --with-cgiurl=/nagios/cgi-bin \
    --with-htmurl=/nagios \
    --with-gd-lib=%{_libdir} \
    --with-gd-inc=%{_includedir}

# bug
perl -pi -e "s|/var/log/nagios/spool/checkresults|/var/spool/nagios/checkresults|g" include/locations.h

%make_build all

# contrib/Makefile contains code to build a rpm, which we do not use.
# It checks for supported archs, breaking builds on 32-bit machines -
# not VMs on 64-bit hardware. Remove the check by setting ARCH to one
# of the supported values for all calls to make in contrib/ .
pushd contrib
    make convertcfg ARCH=i686
    make daemonchk.cgi ARCH=i686
popd

%install
make \
    DESTDIR=%{buildroot} \
    BINDIR=%{_sbindir} \
    CFGDIR=%{_sysconfdir}/nagios \
    CGIDIR=%{_libdir}/nagios/cgi \
    COMMAND_OPTS="" \
    HTMLDIR=%{_datadir}/nagios/www \
    INIT_OPTS="" \
    INSTALL=install \
    INSTALL_OPTS="" \
    LOGDIR=/var/log/nagios \
    STRIP=/bin/true \
    install \
    install-devel \
    install-config

pushd contrib
make \
    DESTDIR=%{buildroot} \
    BINDIR=%{_sbindir} \
    CFGDIR=%{_sysconfdir}/nagios \
    CGIDIR=%{_libdir}/nagios/cgi \
    COMMAND_OPTS="" \
    HTMLDIR=%{_datadir}/nagios/www \
    INIT_OPTS="" \
    INSTALL=install \
    INSTALL_OPTS="" \
    LOGDIR=/var/log/nagios \
    ARCH=i686 \
    install
popd

# fix strange perms
find %{buildroot}%{_datadir}/nagios -type d | xargs chmod 755
find %{buildroot}%{_datadir}/nagios -type f | xargs chmod 644
find %{buildroot}%{_sysconfdir}/nagios -type d | xargs chmod 755
find %{buildroot}%{_sysconfdir}/nagios -type f | xargs chmod 644
chmod 755 \
    %{buildroot}%{_libdir}/nagios/cgi/* \
    %{buildroot}%{_sbindir}/*

# fix docs
cp sample-config/README README.sample-config
cp sample-config/template-object/README README.template-object

# install headers
install -d -m 755 %{buildroot}%{_includedir}/nagios
install -m 644 include/locations.h %{buildroot}%{_includedir}/nagios/
%multiarch_includes %{buildroot}%{_includedir}/nagios/locations.h

install -d -m 755 %{buildroot}/var/spool/nagios/checkresults

# add a placeholder directory for all object configuration files
install -d -m 755 %{buildroot}%{_sysconfdir}/nagios/conf.d

# transfert relevant files from sample configuration there
for file in commands contacts timeperiods templates localhost; do
    mv %{buildroot}%{_sysconfdir}/nagios/objects/$file.cfg \
        %{buildroot}%{_sysconfdir}/nagios/conf.d
done

# drop others
rm -rf %{buildroot}%{_sysconfdir}/nagios/objects

# adapt default configuration
perl -pi \
    -e 's|^check_for_updates=1|check_for_updates=0|;' \
    -e 's|^#query_socket=|query_socket=|;' \
    -e 's|=/var/log/nagios/rw|=/var/spool/nagios|;' \
    %{buildroot}%{_sysconfdir}/nagios/nagios.cfg

perl -pi \
    -e 's|^physical_html_path=.*|physical_html_path=%{_datadir}/nagios/www|;' \
    %{buildroot}%{_sysconfdir}/nagios/cgi.cfg

# systemd
install -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/nagios.service
install -D -m 644 %{SOURCE2} %{buildroot}%{_prefix}/lib/tmpfiles.d/nagios.conf

# apache configuration
install -d -m 755 %{buildroot}%{_webappconfdir}
cat > %{buildroot}%{_webappconfdir}/%{name}.conf <<EOF
# Nagios Apache configuration

ScriptAlias /%{name}/cgi-bin %{_libdir}/%{name}/cgi

<Directory %{_libdir}/%{name}/cgi>
    Options ExecCGI
    Require all granted
</Directory>

Alias /%{name} %{_datadir}/%{name}/www

<Directory %{_datadir}/%{name}>
    Require all granted
</Directory>
EOF

# install and fix event handlers
install -d -m 755 %{buildroot}%{_libdir}/nagios/plugins/eventhandlers
pushd contrib/eventhandlers/
install -m 755 \
    disable_active_service_checks \
    disable_notifications \
    enable_active_service_checks \
    enable_notifications \
    submit_check_result \
    distributed-monitoring/obsessive_svc_handler \
    distributed-monitoring/submit_check_result_via_nsca \
    redundancy-scenario1/handle-master-host-event \
    redundancy-scenario1/handle-master-proc-event \
    %{buildroot}%{_libdir}/nagios/plugins/eventhandlers
popd

find %{buildroot}%{_libdir}/nagios/plugins/eventhandlers -type f | \
    xargs perl -pi \
    -e 's|/usr/local/nagios/var/rw/|/var/spool/nagios/|;' \
    -e 's|/usr/local/nagios/libexec/eventhandlers|%{_libdir}/nagios/plugins/eventhandlers|g;' \
    -e 's|/usr/local/nagios/libexec/send_nsca|%{_libdir}/nagios/plugins/send_nsca|g;' \
    -e 's|/usr/local/nagios/test/var|/var/log/nagios|g;' \
    -e 's|/usr/local/nagios/etc/send_nsca.cfg|%{_sysconfdir}/nagios/send_nsca.cfg|g;' \
    -e 's|printfcmd="/bin/printf"|printfcmd="/usr/bin/printf"|;'

# install the favicon.ico
install -m 644 %{SOURCE5} %{buildroot}%{_datadir}/nagios/www

# rpm filetriggers
%transfiletriggerin -- %{_sysconfdir}/nagios/conf.d
/usr/bin/systemctl reload-or-try-restart nagios.service

%pre
%_pre_useradd %{nsusr} /var/log/nagios /bin/sh
%{_bindir}/gpasswd -a %{cmdusr} %{nsgrp} >/dev/null 2>&1 || :

%post
%_tmpfilescreate %{name}
%_post_service %{name}

%preun
%_preun_service %{name}

%postun
%_postun_userdel %{nsusr}

%files
%doc Changelog INSTALLING LEGAL README.md UPGRADING
%doc sample-config/mrtg.cfg
%{_unitdir}/nagios.service
%{_prefix}/lib/tmpfiles.d/nagios.conf
%{_sbindir}/*
%dir %{_sysconfdir}/nagios
%dir %{_sysconfdir}/nagios/conf.d
%config(noreplace) %{_sysconfdir}/nagios/*.cfg
%config(noreplace) %{_sysconfdir}/nagios/conf.d/*.cfg
%attr(-,%{nsusr},%{nsgrp}) %dir /var/log/nagios
%attr(-,%{nsusr},%{nsgrp}) %dir /var/log/nagios/archives
%attr(2775,%{nsusr},%{cmdgrp}) %dir /var/spool/nagios
%attr(-,%{nsusr},%{nsgrp}) %dir /var/spool/nagios/checkresults
%{_libdir}/nagios/plugins/eventhandlers

%files www
%config(noreplace) %{_webappconfdir}/nagios.conf
%{_libdir}/nagios/cgi
%{_datadir}/nagios/www

%files devel
%multiarch %{multiarch_includedir}/nagios/locations.h
%{_includedir}/nagios
%{_libdir}/libnagios.a


%changelog
* Thu Feb 16 2023 guillomovitch <guillomovitch> 1:4.4.10-1.mga9
+ Revision: 1943485
- new version 4.4.10

* Sat Nov 19 2022 guillomovitch <guillomovitch> 1:4.4.9-1.mga9
+ Revision: 1908858
- new version 4.4.9

* Tue Oct 25 2022 guillomovitch <guillomovitch> 1:4.4.8-1.mga9
+ Revision: 1899348
- new version 4.4.8

* Thu Sep 29 2022 guillomovitch <guillomovitch> 1:4.4.7-1.mga9
+ Revision: 1893123
- new version 4.4.7

* Thu Mar 31 2022 umeabot <umeabot> 1:4.4.6-3.mga9
+ Revision: 1837723
- Mageia 9 Mass Rebuild

* Wed Jul 22 2020 mokraemer <mokraemer> 1:4.4.6-2.mga8
+ Revision: 1607872
- resolve mod_php conflict

* Tue May 12 2020 guillomovitch <guillomovitch> 1:4.4.6-1.mga8
+ Revision: 1583397
- new version 4.4.6

* Mon Feb 17 2020 umeabot <umeabot> 1:4.4.5-3.mga8
+ Revision: 1537114
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Oct 26 2019 cjw <cjw> 1:4.4.5-2.mga8
+ Revision: 1455827
- fix build on 32-bit arm hardware

* Fri Aug 30 2019 guillomovitch <guillomovitch> 1:4.4.5-1.mga8
+ Revision: 1435769
- new version 4.4.5

* Thu Aug 15 2019 guillomovitch <guillomovitch> 1:4.4.4-1.mga8
+ Revision: 1429355
- new version 4.4.4

* Tue Mar 19 2019 pterjan <pterjan> 1:4.4.3-2.mga7
+ Revision: 1378892
- Add again a patch to fix build on other architectures

* Sat Jan 19 2019 guillomovitch <guillomovitch> 1:4.4.3-1.mga7
+ Revision: 1358076
- new version 4.4.3

* Fri Sep 07 2018 guillomovitch <guillomovitch> 1:4.4.2-1.mga7
+ Revision: 1257662
- new version 4.4.2

* Sun Jul 22 2018 wally <wally> 1:4.4.1-2.mga7
+ Revision: 1244796
- add patch originally from Fedora to remove rpmbuild parts from contrib Makefile (to fix build on aarch64)
- use mga optflags

* Thu Jul 05 2018 guillomovitch <guillomovitch> 1:4.4.1-1.mga7
+ Revision: 1241996
- new version 4.4.1
- drop old compatibility symlink /etc/nagios/plugins.d

* Mon Sep 18 2017 guillomovitch <guillomovitch> 1:4.3.4-1.mga7
+ Revision: 1155294
- new version 4.3.4

* Fri Jul 07 2017 luigiwalser <luigiwalser> 1:4.3.1-2.mga6
+ Revision: 1109370
- apply upstreamed patch from me to fix CVE-2016-10089

* Sun May 07 2017 guillomovitch <guillomovitch> 1:4.3.1-1.mga6
+ Revision: 1099524
- new version 4.3.1

* Mon Dec 19 2016 guillomovitch <guillomovitch> 1:4.2.4-1.mga6
+ Revision: 1076159
- new version 4.2.4 (fix CVE 2016-9565 and CVE 2016-9566)

* Sat Dec 10 2016 ngompa <ngompa> 1:4.1.1-5.mga6
+ Revision: 1074091
- Remove unneeded %%pretrans

* Sun Nov 27 2016 wally <wally> 1:4.1.1-4.mga6
+ Revision: 1070369
- drop unneeded requires for freetype pkgs

* Wed Mar 30 2016 pterjan <pterjan> 1:4.1.1-3.mga6
+ Revision: 996982
- Fix Makefile on non x86

* Sat Feb 20 2016 umeabot <umeabot> 1:4.1.1-2.mga6
+ Revision: 971195
- Mageia 6 Mass Rebuild

* Sun Oct 11 2015 guillomovitch <guillomovitch> 1:4.1.1-1.mga6
+ Revision: 889746
- new version 4.1.1
  switch to new filetrigger implementation

* Mon Feb 16 2015 oden <oden> 1:4.0.8-2.mga5
+ Revision: 815156
- rebuilt for libgd-2.1.1

* Sun Nov 09 2014 guillomovitch <guillomovitch> 1:4.0.8-1.mga5
+ Revision: 796132
- new version 4.0.8

* Wed Oct 15 2014 umeabot <umeabot> 1:4.0.7-3.mga5
+ Revision: 742428
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1:4.0.7-2.mga5
+ Revision: 682762
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Mon Jun 23 2014 guillomovitch <guillomovitch> 1:4.0.7-1.mga5
+ Revision: 638798
- new version 4.0.7

* Mon Apr 21 2014 luigiwalser <luigiwalser> 1:4.0.2-2.mga5
+ Revision: 617340
- add patch from icinga via opensuse to fix CVE-2014-1878

* Tue Dec 31 2013 guillomovitch <guillomovitch> 1:4.0.2-1.mga4
+ Revision: 563550
- new version 4.0.2
- add upstream patch to fix CVE-2013-7108 and CVE-2013-7205

* Tue Nov 12 2013 dlucio <dlucio> 1:4.0.1-1.mga4
+ Revision: 550860
- 4.0.1
- setup directory fix

* Mon Oct 21 2013 umeabot <umeabot> 1:4.0.0-2.mga4
+ Revision: 539497
- Mageia 4 Mass Rebuild

* Sun Oct 06 2013 guillomovitch <guillomovitch> 1:4.0.0-1.mga4
+ Revision: 492345
- new version 4.0
- reduce the default sample configuration for sake of readability
- use more generic conf.d instead of plugins.d as default drop-in directory
- fix tempfile creation at package installation

* Sun Sep 29 2013 guillomovitch <guillomovitch> 1:3.5.1-2.mga4
+ Revision: 489245
- drop unwanted and uselessly complex authentication from default apache configuration
- drop uselessly complex pre-execution configuration hack from systemd service
- reintroduce standard %%{_webappconfdir} macro

* Sun Sep 01 2013 guillomovitch <guillomovitch> 1:3.5.1-1.mga4
+ Revision: 473998
- new version

* Thu Aug 01 2013 alien <alien> 1:3.5.0-3.mga4
+ Revision: 462396
- Use BasicAuth by default
- split off localhost checks into subpackage (it conflicts with check_mk-localhost)
- move the apache webapp conf to the correct location
- implement reloading the nagios service
- hack a way to have a config directory for broker modules
- allow the nagiosadmin user admin access
- put the localhost config in the right place

* Mon May 27 2013 oden <oden> 1:3.5.0-2.mga4
+ Revision: 428750
- rebuilt against libgd.so.3

* Thu May 23 2013 guillomovitch <guillomovitch> 1:3.5.0-1.mga4
+ Revision: 424811
- new version

* Fri Feb 15 2013 dlucio <dlucio> 1:3.4.4-4.mga3
+ Revision: 398589
- New provides to let NRPE or Nagios be choosen for plugins

* Thu Feb 07 2013 guillomovitch <guillomovitch> 1:3.4.4-3.mga3
+ Revision: 395124
- drop command definition from default configuration to avoid conflict with definitions found in plugin packages
- soft dependency on plugins used in default configuration (#8986)

* Wed Feb 06 2013 guillomovitch <guillomovitch> 1:3.4.4-2.mga3
+ Revision: 394811
- switch group to monitoring

* Sun Jan 27 2013 guillomovitch <guillomovitch> 1:3.4.4-1.mga3
+ Revision: 392788
- new version

* Sat Jan 12 2013 umeabot <umeabot> 1:3.4.3-2.mga3
+ Revision: 360674
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Dec 10 2012 guillomovitch <guillomovitch> 1:3.4.3-1.mga3
+ Revision: 329333
- new version

* Wed Sep 05 2012 guillomovitch <guillomovitch> 1:3.4.1-8.mga3
+ Revision: 288650
- cleanup installation process, and ensure standard perms

* Fri Aug 24 2012 guillomovitch <guillomovitch> 1:3.4.1-7.mga3
+ Revision: 283391
- make webapp configuration file compliant with apache 2.4

* Thu Aug 23 2012 guillomovitch <guillomovitch> 1:3.4.1-6.mga3
+ Revision: 283355
- don't ship /var/run/nagios

* Fri Jul 06 2012 guillomovitch <guillomovitch> 1:3.4.1-5.mga3
+ Revision: 268427
- fix rpm filetrigger to use systemctl instead of systemd init script

* Thu Jun 07 2012 guillomovitch <guillomovitch> 1:3.4.1-4.mga3
+ Revision: 256947
- fix www package dependencies

* Tue Jun 05 2012 guillomovitch <guillomovitch> 1:3.4.1-3.mga3
+ Revision: 255980
- don't turn off default syslog log duplication
- use /usr/lib/tmpfiles.d for temp files definitions

* Tue Jun 05 2012 guillomovitch <guillomovitch> 1:3.4.1-2.mga3
+ Revision: 255896
- add systemd support
- drom sysinit support
- drop old mergecfg script

* Mon Jun 04 2012 guillomovitch <guillomovitch> 1:3.4.1-1.mga3
+ Revision: 254077
- new version
- merge default-theme package into www package
- add mod_php dependency for www package

* Sun Sep 18 2011 misc <misc> 1:3.3.1-2.mga2
+ Revision: 145053
- fix init script lsb keyword
+ dmorgan <dmorgan>
- Change apache-conf require
+ guillomovitch <guillomovitch>
- the theme package is noarch
- patch3: fix issue with rss files installation
- use standard %%_pre_useradd macro
- more spec cleanup
- drop useless XDG menu
- new version
- spec cleanup
- drop README.mdv, information provided there is just about packaging changes
- drop obsolete migration %%post scripts
- drop useless external configuration package
- no need for arbitrary default configuration structure, let the user do it

* Thu Mar 03 2011 ennael <ennael> 1:3.2.3-2.mga1
+ Revision: 63044
- clean spec file
- imported package nagios


* Sat Feb 05 2011 Funda Wang <fwang@mandriva.org> 1:3.2.3-2mdv2011.0
+ Revision: 636326
- tighten BR

* Wed Oct 06 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1:3.2.3-1mdv2011.0
+ Revision: 583635
- new version
- drop format error patch, merged upstream

* Sun Sep 05 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1:3.2.2-1mdv2011.0
+ Revision: 576159
- new version

* Wed Aug 11 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1:3.2.1-2mdv2011.0
+ Revision: 569136
- rebuild for new perl
- fix binaries perms

* Sat Mar 27 2010 Thierry Vignaud <tv@mandriva.org> 1:3.2.1-1mdv2010.1
+ Revision: 528045
- new release

* Wed Feb 17 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1:3.2.0-7mdv2010.1
+ Revision: 507286
- rely on filetrigger for reloading apache configuration begining with 2010.1, rpm-helper macros otherwise
- switch to "open to all" default access policy

* Sat Jan 16 2010 Funda Wang <fwang@mandriva.org> 1:3.2.0-6mdv2010.1
+ Revision: 492259
- rebuild for new libjpeg v8

* Fri Dec 04 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1:3.2.0-5mdv2010.1
+ Revision: 473483
- better apache configuration

* Mon Nov 30 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1:3.2.0-4mdv2010.1
+ Revision: 472077
- restrict default access permissions to localhost only, as per new policy

* Wed Sep 09 2009 Frederik Himpe <fhimpe@mandriva.org> 1:3.2.0-3mdv2010.0
+ Revision: 435783
- Rebuild for new perl

* Mon Aug 17 2009 Oden Eriksson <oeriksson@mandriva.com> 1:3.2.0-2mdv2010.0
+ Revision: 417293
- rebuilt against libjpeg v7

* Thu Aug 13 2009 Oden Eriksson <oeriksson@mandriva.com> 1:3.2.0-1mdv2010.0
+ Revision: 416025
- 3.2.0

* Sun Jul 19 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1:3.1.2-2mdv2010.0
+ Revision: 397904
- merge README.mandriva and README.urpmi in a single README.mdv file, and use an herein document for it
- drop old 2006.0 menu entr
- cleanup %%files section
- drop overcomplex password generation at install-time, and ship a minimal apache configuration file, admins are supposed smart enough to configure suited protection themselves
- drop useless explicit dependencies
- spec cleanup
- build mini_epn
- allow translations in initscript
- drop useless optflag patch
- use make argument instead of a patch to avoid stripping
- no need to regenerate autotools suite

* Wed Jul 01 2009 Oden Eriksson <oeriksson@mandriva.com> 1:3.1.2-1mdv2010.0
+ Revision: 391239
- bump release
- 3.1.2

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - fix default physical_html_path in cgi.cfg

* Sun Jan 25 2009 Oden Eriksson <oeriksson@mandriva.com> 1:3.1.0-1mdv2009.1
+ Revision: 333546
- 3.1.0
- fix build with -Werror=format-security (P7)
- don't activate the check_for_updates feature per default (P8)

* Tue Dec 30 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1:3.0.6-3mdv2009.1
+ Revision: 321471
- enable embedded perl
- substitute files only, not directories
- fix more file perms
- move web pages under %%{_datadir}/nagios/www, to avoid having plugins under web root

* Mon Dec 15 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1:3.0.6-2mdv2009.1
+ Revision: 314622
- add file triggers to reload nagios when adding plugins
- rename apache configuration file according to webapps policy, while
  moving old one to avoid #45963
- rediff patch 0 for no fuzz
- fix init script logic: cmd and pid files should be deleted if present, not if missing

  + Oden Eriksson <oeriksson@mandriva.com>
    - lowercase ImageMagick

* Tue Dec 02 2008 Oden Eriksson <oeriksson@mandriva.com> 1:3.0.6-1mdv2009.1
+ Revision: 309178
- 3.0.6 (Minor security fixes)

* Mon Nov 24 2008 Oden Eriksson <oeriksson@mandriva.com> 1:3.0.5-2mdv2009.1
+ Revision: 306324
- fix #45963 (Move of configuration file breaks custom configurations)

* Wed Nov 05 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1:3.0.5-1mdv2009.1
+ Revision: 300019
- new version
- don't version apache configuration file

* Thu Oct 16 2008 Oden Eriksson <oeriksson@mandriva.com> 1:3.0.4-1mdv2009.1
+ Revision: 294138
- 3.0.4

* Fri Jul 04 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1:3.0.3-2mdv2009.0
+ Revision: 231681
- yet another event handlers fix

* Thu Jun 26 2008 Oden Eriksson <oeriksson@mandriva.com> 1:3.0.3-1mdv2009.0
+ Revision: 229226
- 3.0.3

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Wed May 21 2008 Oden Eriksson <oeriksson@mandriva.com> 1:3.0.2-0.1mdv2009.0
+ Revision: 209800
- 3.0.2

* Thu May 15 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1:3.0.1-2mdv2009.0
+ Revision: 207546
- change the dependency in initscript from mysql to ndo2db

* Wed Apr 02 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1:3.0.1-1mdv2008.1
+ Revision: 191564
- new version (bugfix release)

* Fri Mar 14 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1:3.0-1mdv2008.1
+ Revision: 187806
- final version

* Wed Feb 27 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1:3.0-0.0.rc3.1mdv2008.1
+ Revision: 175745
- new version

* Thu Feb 14 2008 Oden Eriksson <oeriksson@mandriva.com> 1:3.0-0.0.rc2.3mdv2008.1
+ Revision: 168479
- make it build on cs4

* Mon Feb 11 2008 Oden Eriksson <oeriksson@mandriva.com> 1:3.0-0.0.rc2.2mdv2008.1
+ Revision: 165278
- fix deps

* Wed Jan 30 2008 Oden Eriksson <oeriksson@mandriva.com> 1:3.0-0.0.rc2.1mdv2008.1
+ Revision: 160236
- 3.0rc2
- drop P2, it's implemented upstream
- fix #36663 (Error message when installing any nagios plug-in)
- make it back portable (old menu system)
- added a README.Mandriva file that hopefully explains more...
- require a new nagios-conf package for tailoring nagios
- partly fix #36662
- fix #36650 (no LSB tags in init script)

  + Thierry Vignaud <tv@mandriva.org>
    - drop old menu

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - own cgi dir, otherwise a restricted root umask make them unusable

* Tue Dec 18 2007 Oden Eriksson <oeriksson@mandriva.com> 1:3.0-0.0.rc1.1mdv2008.1
+ Revision: 132454
- 3.0rc1
- fix a %%postun error
- 3.0b7
- rediffed P6
- fix the apache config (duh!)

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request
    - buildrequires X11-devel instead of XFree86-devel

* Thu Nov 01 2007 Oden Eriksson <oeriksson@mandriva.com> 1:3.0-0.0.b6.1mdv2008.1
+ Revision: 104437
- 3.0b6

* Fri Oct 12 2007 Oden Eriksson <oeriksson@mandriva.com> 1:3.0-0.0.b5.1mdv2008.1
+ Revision: 97364
- 3.0b5

* Fri Sep 28 2007 Oden Eriksson <oeriksson@mandriva.com> 1:3.0-0.0.b4.1mdv2008.0
+ Revision: 93545
- 3.0b4
- drop P3, it was allready applied

* Sun Sep 09 2007 Oden Eriksson <oeriksson@mandriva.com> 1:3.0-0.0.b3.4mdv2008.0
+ Revision: 83456
- whoops!, it was the other way around :)

* Sun Sep 09 2007 Oden Eriksson <oeriksson@mandriva.com> 1:3.0-0.0.b3.3mdv2008.0
+ Revision: 83454
- fix the apache config
- fix the %%pre and %%post scriptlets

* Fri Sep 07 2007 Oden Eriksson <oeriksson@mandriva.com> 1:3.0-0.0.b3.2mdv2008.0
+ Revision: 81569
- fix correct path to checkresults

* Sat Sep 01 2007 Oden Eriksson <oeriksson@mandriva.com> 1:3.0-0.0.b3.1mdv2008.0
+ Revision: 77372
- 3.0b3
- rediffed patches

* Thu Aug 23 2007 Thierry Vignaud <tv@mandriva.org> 1:2.9-5mdv2008.0
+ Revision: 70376
- fileutils, sh-utils & textutils have been obsoleted by coreutils a long time ago

* Tue Jul 24 2007 Oden Eriksson <oeriksson@mandriva.com> 1:2.9-4mdv2008.0
+ Revision: 55004
- use the new %%serverbuild macro

* Mon Jun 25 2007 Oden Eriksson <oeriksson@mandriva.com> 1:2.9-3mdv2008.0
+ Revision: 43826
- fix deps

* Thu Jun 14 2007 Oden Eriksson <oeriksson@mandriva.com> 1:2.9-2mdv2008.0
+ Revision: 39298
- use distro conditional -fstack-protector

* Tue Apr 17 2007 Oden Eriksson <oeriksson@mandriva.com> 1:2.9-1mdv2008.0
+ Revision: 13743
- 2.9
- 2.9


* Thu Jan 25 2007 Oden Eriksson <oeriksson@mandriva.com> 2.7-1mdv2007.0
+ Revision: 113174
- 2.7
- make it backportable

* Thu Nov 30 2006 Oden Eriksson <oeriksson@mandriva.com> 1:2.6-1mdv2007.1
+ Revision: 89047
- 2.6
- remove obsolete patches and add one new one
- remove obsolete sources
- generate a password if needed for the nagios web user
- added a README.urpmi file outlining the changes

* Wed Nov 15 2006 Oden Eriksson <oeriksson@mandriva.com> 1:2.5-5mdv2007.1
+ Revision: 84428
- Import nagios

* Wed Nov 15 2006 Oden Eriksson <oeriksson@mandriva.com> 1:2.5-6mdv2007.1
- use the www-browser script instead
- fix the xdg menu
- remove conditional build switches for unsupported distros
- bunzip sources

* Thu Sep 07 2006 Oden Eriksson <oeriksson@mandriva.com> 1:2.5-5mdv2007.0
- don't enforce ssl redirect

* Fri Aug 04 2006 Oden Eriksson <oeriksson@mandriva.com> 1:2.5-4mdv2007.0
- fix typo

* Thu Aug 03 2006 Oden Eriksson <oeriksson@mandriva.com> 1:2.5-3mdv2007.0
- fix xdg menu stuff

* Thu Aug 03 2006 Oden Eriksson <oeriksson@mandriva.com> 1:2.5-2mdv2007.0
- fix deps

* Sat Jul 15 2006 Oden Eriksson <oeriksson@mandriva.com> 1:2.5-1mdv2007.0
- 2.5 (Minor bugfixes)

* Mon Jul 03 2006 Emmanuel Andry <eandry@mandriva.org> 1:2.4-2mdv2007.0
- fix buildrequires

* Fri Jun 02 2006 Oden Eriksson <oeriksson@mandriva.com> 1:2.4-1mdv2007.0
- 2.4 (Minor bugfixes)
- rediffed P8

* Wed May 17 2006 Oden Eriksson <oeriksson@mandriva.com> 1:2.3.1-1mdk
- 2.3.1 (Major security fixes)

* Sun May 14 2006 Oden Eriksson <oeriksson@mandriva.com> 1:2.3-3mdk
- fix better apache config

* Thu May 11 2006 Oden Eriksson <oeriksson@mandriva.com> 1:2.3-2mdk
- fix deps
- relocate the /admin/nagios url to /nagios
- fix better apache config
- fix a menuentry

* Fri May 05 2006 Oden Eriksson <oeriksson@mandriva.com> 1:2.3-1mdk
- 2.3 (Minor security fixes)

* Sun Apr 09 2006 Oden Eriksson <oeriksson@mandriva.com> 2.2-1mdk
- 2.2 (Minor bugfixes)

* Sat Apr 08 2006 Oden Eriksson <oeriksson@mandriva.com> 1:2.1-2mdk
- fix deps and #20711

* Tue Mar 28 2006 Oden Eriksson <oeriksson@mandriva.com> 1:2.1-1mdk
- 2.1 (Minor bugfixes)

* Thu Feb 23 2006 Oden Eriksson <oeriksson@mandriva.com> 1:2.0-3mdk
- install the apache config depending on distro

* Tue Feb 14 2006 Oden Eriksson <oeriksson@mandriva.com> 1:2.0-2mdk
- fix deps

* Wed Feb 08 2006 Oden Eriksson <oeriksson@mandriva.com> 1:2.0-1mdk
- 2.0 (Minor bugfixes)

* Wed Jan 11 2006 Oden Eriksson <oeriksson@mandriva.com> 2.0rc2-1mdk
- 2.0rc2 (Minor bugfixes)
- rediffed P2

* Thu Dec 01 2005 Oden Eriksson <oeriksson@mandriva.com> 2.0b6-1mdk
- 2.0b5 (Minor bugfixes)

* Tue Nov 15 2005 Oden Eriksson <oeriksson@mandriva.com> 2.0b5-1mdk
- 2.0b5 (Minor bugfixes)
- remove strip calls (P8)

* Wed Oct 19 2005 Oden Eriksson <oeriksson@mandriva.com> 2.0b4-2mdk
- fix #19312

* Thu Aug 04 2005 Oden Eriksson <oeriksson@mandriva.com> 2.0b4-1mdk
- 2.0b4 (Minor bugfixes)
- fix %%post and %%postun for the nagios-www package
- fix deps

* Tue May 31 2005 Oden Eriksson <oeriksson@mandriva.com> 2.0b4-0.20050530.1mdk
- use a recent snap (20050530)
- added a nice favicon.ico patch by PLD (S5 & P6)
- added a patch by Andreas Ericsson (P7)

* Thu May 26 2005 Oden Eriksson <oeriksson@mandriva.com> 2.0b3-2mdk
- fix #13814

* Tue Apr 05 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 2.0b3-1mdk
- 2.0b3
- added P5 to make the shipped minimalistic config work again

* Mon Apr 04 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 2.0b2-4mdk
- use the %%mkrel macro

* Sat Feb 19 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 2.0b2-3mdk
- added P4 to bring back some missing stuff
- handle the %%postun better

* Fri Feb 18 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 2.0b2-2mdk
- spec file cleanups, remove the ADVX-build stuff

* Thu Feb 10 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 2.0b2-1mdk
- 2.0b2
- rediffed P0
- make it compile on x86_64

* Thu Feb 10 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 2.0a1-0.20041024.3mdk
- set LC_ALL=C in the initscript in an attempt to fix #12740 like future issues
- fix deps and conditional %%multiarch

* Mon Nov 29 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 2.0a1-0.20041024.2mdk
- added S2
- enhanced the init scipt a bit (S1)

* Mon Oct 25 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 2.0a1-0.20041024.1mdk
- 20041024

* Mon Oct 04 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 2.0a1-0.20041002.2mdk
- fix one typo

* Mon Oct 04 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 2.0a1-0.20041002.1mdk
- cvs snap 20041002 of 2.0a1
- added the long forgotten eventhandlers
- new S2
- added P2 & P3
- misc spec file fixes

* Tue Jul 06 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 1.2-4mdk
- added P1 to make it recognize the correct gd stuff

* Sat Jun 12 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 1.2-3mdk
- rebuilt against new gd

* Sun May 16 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 1.2-2mdk
- fix #9762 (revert changes in 1.2-1mdk)
- fix deps

* Wed Mar 03 2004 Tibor Pittich <Tibor.Pittich@mandrake.org> 1.2-1mdk
- 1.2
- fixed 12_nagios.conf

